# Vyro ドキュメント

Vyro は、Python DX と Rust 実行エンジンを組み合わせて、高性能 API を実現します。

## あなたにできること

- `Vyro()` を使用して非同期 API を構築する
- `vyro run` でサービスを実行する
- OpenAPI を使用して API コントラクトを生成する
- 可観測性とセキュリティプリミティブを備えた運用サービスを運用する

## ここから始めましょう

1. [インストール](getting-started/installation.md)を読みます。
2. [クイックスタート](getting-started/quickstart.md)に従ってください。
3. [最初の API](getting-started/first-api.md) で最初のエンドポイントを構築します。